AddMarker class final

Inheritance

Constructors

AddMarker({required MarkerOption markerOption, required String layerId})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
layerId String
final
markerOption MarkerOption
final
name String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(Object? value) → void
inherited
encode() Map<String, Object?>?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited