ScaleBar class

Scale bar configuration EN

  • Displays current map scale with optional auto-hide behavior

KO

  • 현재 지도 축척을 표시하며 자동 숨김 동작을 지원

Constructors

ScaleBar({bool isAutoHide = false, int fadeInTime = 300, int fadeOutTime = 300, int retentionTime = 3000})
Create configuration EN
const
ScaleBar.fromJson(Map<String, Object?> json)
From JSON map
factory

Properties

fadeInTime int
Fade-in time (ms)
final
fadeOutTime int
Fade-out time (ms)
final
hashCode int
The hash code for this object.
no setterinherited
isAutoHide bool
Auto-hide enabled
final
retentionTime int
Retention time before auto-hide (ms)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Serialize to JSON EN
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited