GuiLayout class
GUI 레이아웃: 여러 GUI 뷰를 포함하는 컨테이너
수평 또는 수직 방향으로 자식 뷰들을 배치하고, 배경 이미지를 설정할 수 있습니다.
Constructors
-
GuiLayout({required Orientation orientation, List<
GuiView> children = const <GuiView>[], GuiImage? background, String id = '', bool clickable = true, int paddingLeft = 0, int paddingTop = 0, int paddingRight = 0, int paddingBottom = 0, Vertical verticalOrigin = Vertical.bottom, Horizontal horizontalOrigin = Horizontal.center, Vertical verticalAlign = Vertical.center, Horizontal horizontalAlign = Horizontal.center, Object? tag}) -
GUI 레이아웃을 생성합니다.
const
Properties
- background → GuiImage?
-
레이아웃의 배경 이미지
final
-
children
→ List<
GuiView> -
레이아웃에 포함된 자식 뷰들
final
- clickable → bool
-
터치 이벤트 수신 여부
finalinherited
- hasChildren → bool
-
자식 뷰가 있는지 확인
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- horizontalAlign → Horizontal
-
수평 뷰 정렬
finalinherited
- horizontalOrigin → Horizontal
-
수평 원점 정렬
finalinherited
- id → String
-
뷰의 고유 식별자
finalinherited
- orientation → Orientation
-
자식 뷰들의 배치 방향
final
- paddingBottom → int
-
아래쪽 패딩
finalinherited
- paddingLeft → int
-
왼쪽 패딩
finalinherited
- paddingRight → int
-
오른쪽 패딩
finalinherited
- paddingTop → int
-
위쪽 패딩
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → Object?
-
추가 데이터 저장 객체
finalinherited
- type → int
-
뷰의 타입
finalinherited
- verticalAlign → Vertical
-
수직 뷰 정렬
finalinherited
- verticalOrigin → Vertical
-
수직 원점 정렬
finalinherited
Methods
-
addChild(
GuiView child) → GuiLayout - 자식 뷰 추가된 새로운 레이아웃 생성
-
getChildAt(
int index) → GuiView? - 인덱스로 자식 뷰 가져오기
-
getChildById(
String id) → GuiView? - ID로 자식 뷰 찾기
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
Serialize to JSON
ENoverride -
toString(
) → String -
A string representation of this object.
inherited
-
withBackground(
GuiImage backgroundImage) → GuiLayout - 배경 이미지가 설정된 새로운 레이아웃 생성
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited