MarkerOption class
Marker option
EN
- Identifier, position and optional style/text for markers
KO
- 마커의 식별자, 위치와 선택적 스타일/텍스트 옵션
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier
final
- latLng → LatLng
-
Geographic position
final
- rank → int?
-
Rendering order
ENfinal - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- styleId → String?
-
Pre-registered style id
ENfinal - text → String?
-
Text content
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
Serialize to JSON
EN -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited